from test.helpers.my_httpretty import MyHTTPretty
import httpretty.core
import httpretty

# Substitute in our version
HTTPretty = MyHTTPretty

httpretty.core.httpretty = MyHTTPretty

# May need to set other module-level attributes here, e.g. enable, reset etc,
# depending on your needs
httpretty.httpretty = MyHTTPretty
httpretty.enable = MyHTTPretty.enable
httpretty.disable = MyHTTPretty.disable



#  tests for quandl-3.4.2-py37_0 (this is a generated file);
print('===== testing package: quandl-3.4.2-py37_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import quandl
import quandl.errors
import quandl.model
import quandl.operations
import quandl.utils

#datasets = quandl.search('OIL')
#print(datasets[0])
#  --- run_test.py (end) ---

print('===== quandl-3.4.2-py37_0 OK =====');
print("import: 'quandl'")
import quandl

print("import: 'quandl.errors'")
import quandl.errors

print("import: 'quandl.model'")
import quandl.model

print("import: 'quandl.operations'")
import quandl.operations

print("import: 'quandl.utils'")
import quandl.utils




from inflection import (underscore, pluralize)


class Operation(object):
    @classmethod
    def default_path(cls):
        return "%s/:id" % cls.lookup_key()

    @classmethod
    def lookup_key(cls):
        return underscore(pluralize(cls.__name__))
